<?php

/**
 * @file
 * Contains \Drupal\drd\Command\DrdActionLibraryCommand.
 */

namespace Drupal\drd\Command;

use Drupal\Console\Style\DrupalStyle;
use Symfony\Component\Console\Helper\HelperSet;
use Symfony\Component\Console\Input\InputArgument;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;

/**
 * Class DrdActionLibraryCommand.
 *
 * @package Drupal\drd
 */
class DrdActionLibraryCommand extends DrdCommandRemoteActionBase {

  public function __construct(HelperSet $helperSet) {
    parent::__construct($helperSet);
    $this->action_key = 'drd_action_library';
  }

  /**
   * {@inheritdoc}
   */
  protected function configure() {
    parent::configure();
    $this
      ->setName('drd:action:library')
      ->setDescription($this->trans('command.drd.action.library.description'))
      ->addArgument(
        'source',
        InputArgument::REQUIRED,
        $this->trans('command.drd.action.library.arguments.source')
      );
  }

  /**
   * {@inheritdoc}
   */
  protected function interact(InputInterface $input, OutputInterface $output) {
    $io = new DrupalStyle($input, $output);

    // source argument
    $source = $input->getArgument('source');
    if (!$source) {
      $source = $io->choice(
        $this->trans('command.drd.action.library.questions.source'),
        ['official', 'local', 'none']
      );
      $input->setArgument('source', $source);
    }

    parent::interact($input, $output);
  }

  /**
   * @inheritDoc
   */
  protected function setActionArguments($action, InputInterface $input) {
    parent::setActionArguments($action, $input);
    $action->setActionArgument('source', $input->getArgument('source'));
  }

}
