<?php

/**
 * @file
 * Contains \Drupal\drd\Command\DrdActionMaintenanceModeCommand.
 */

namespace Drupal\drd\Command;

use Drupal\Console\Style\DrupalStyle;
use Symfony\Component\Console\Helper\HelperSet;
use Symfony\Component\Console\Input\InputArgument;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;

/**
 * Class DrdActionMaintenanceModeCommand.
 *
 * @package Drupal\drd
 */
class DrdActionMaintenanceModeCommand extends DrdCommandRemoteActionBase {

  public function __construct(HelperSet $helperSet) {
    parent::__construct($helperSet);
    $this->action_key = 'drd_action_maintenance_mode';
  }

  /**
   * {@inheritdoc}
   */
  protected function configure() {
    parent::configure();
    $this
      ->setName('drd:action:maintenancemode')
      ->setDescription($this->trans('command.drd.action.maintenancemode.description'))
      ->addArgument(
        'mode',
        InputArgument::REQUIRED,
        $this->trans('command.drd.action.maintenancemode.arguments.mode')
      );
  }

  /**
   * {@inheritdoc}
   */
  protected function interact(InputInterface $input, OutputInterface $output) {
    $io = new DrupalStyle($input, $output);

    // source argument
    $mode = $input->getArgument('mode');
    if (!$mode) {
      $mode = $io->choice(
        $this->trans('command.drd.action.maintenancemode.questions.source'),
        ['getStatus', 'on', 'off']
      );
      $input->setArgument('mode', $mode);
    }

    parent::interact($input, $output);
  }

  /**
   * @inheritDoc
   */
  protected function setActionArguments($action, InputInterface $input) {
    parent::setActionArguments($action, $input);
    $action->setActionArgument('mode', $input->getArgument('mode'));
  }

}
