<?php

/**
 * @file
 * Contains \Drupal\drd\Command\DrdCommandRemoteActionBase.
 */

namespace Drupal\drd\Command;

use Drupal\drd\Entity\DrdDomain;
use Drupal\drd\Plugin\DrdActionRemoteBase;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Input\InputOption;
use Symfony\Component\Console\Output\OutputInterface;

/**
 * Class DrdCommandRemoteActionBase.
 *
 * @package Drupal\drd
 */
abstract class DrdCommandRemoteActionBase extends DrdCommandActionBase {

  /**
   * {@inheritdoc}
   */
  protected function configure() {
    parent::configure();
    $this
      ->addOption(
        'domain-id',
        NULL,
        InputOption::VALUE_OPTIONAL,
        $this->trans('command.drd.actions.remote.arguments.domain-id')
      );
  }

  /**
   * {@inheritdoc}
   */
  protected function execute(InputInterface $input, OutputInterface $output) {
    $action = parent::execute($input, $output);

    if (empty($action) || !($action instanceof DrdActionRemoteBase)) {
      $output->writeln('No valid remote action!');
      return;
    }

    $domain_id = $input->getOption('domain-id');
    if ($domain_id) {
      $domain = \Drupal::entityTypeManager()
          ->getStorage('drd_domain')
          ->load($domain_id);
      $domains = empty($domain) ? [] : [$domain];
    }
    else {
      $domains = \Drupal::entityTypeManager()
        ->getStorage('drd_domain')
        ->loadByProperties([
          'status' => 1,
          'installed' => 1,
        ]);
    }
    if (empty($domains)) {
      $output->writeln('No domain found!');
      return;
    }
    $output->writeln('Executing ' . $action->getPluginDefinition()['label']);
    foreach ($domains as $domain) {
      /** @var DrdDomain $domain */
      $output->writeln('- on ' . $domain->getName());
      if ($action->execute($domain) !== FALSE) {
        $response = $action->getResponse();
        if (is_array($response) && !empty($response['output'])) {
          $output->writeln('  ' . $response['output']);
        }
        $output->writeln('  ok!');
      }
      else {
        $output->writeln('  failure!');
      }
    }

    $output->writeln('Completed!');
  }

}
