<?php

/**
 * @file
 * Contains \Drupal\drd\Command\DrdCommandRemoteCoreActionBase.
 */

namespace Drupal\drd\Command;

use Drupal\drd\Entity\DrdCore;
use Drupal\drd\Plugin\DrdActionRemoteBase;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Input\InputOption;
use Symfony\Component\Console\Output\OutputInterface;

/**
 * Class DrdCommandRemoteCoreActionBase.
 *
 * @package Drupal\drd
 */
abstract class DrdCommandRemoteCoreActionBase extends DrdCommandActionBase {

  /**
   * {@inheritdoc}
   */
  protected function configure() {
    parent::configure();
    $this
      ->addOption(
        'core-id',
        NULL,
        InputOption::VALUE_OPTIONAL,
        $this->trans('command.drd.actions.remote.arguments.core-id')
      );
  }

  /**
   * {@inheritdoc}
   */
  protected function execute(InputInterface $input, OutputInterface $output) {
    $action = parent::execute($input, $output);

    if (empty($action) || !($action instanceof DrdActionRemoteBase)) {
      $output->writeln('No valid remote action!');
      return;
    }

    $core_id = $input->getOption('core-id');
    if ($core_id) {
      $cores = [
        \Drupal::entityTypeManager()
          ->getStorage('drd_core')
          ->load($core_id)
      ];
    }
    else {
      $cores = \Drupal::entityTypeManager()
        ->getStorage('drd_core')
        ->loadByProperties([
          'status' => 1,
        ]);
    }
    $output->writeln('Executing ' . $action->getPluginDefinition()['label']);
    foreach ($cores as $core) {
      /** @var DrdCore $core */
      $output->writeln('- on ' . $core->getName());
      if ($action->execute($core)) {
        $response = $action->getResponse();
        if (is_array($response) && !empty($response['output'])) {
          $output->writeln('  ' . $response['output']);
        }
        $output->writeln('  ok!');
      }
      else {
        $output->writeln('  failure!');
      }
    }

    $output->writeln('Completed!');
  }

}
