<?php

/**
 * @file
 * Contains \Drupal\drd\Command\DrdMigrateFromD7Command.
 */

namespace Drupal\drd\Command;

use Drupal\Component\Serialization\Json;
use Drupal\drd\Entity\DrdCore;
use Drupal\drd\Entity\DrdDomain;
use Drupal\drd\Entity\DrdHost;
use Symfony\Component\Console\Input\InputArgument;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;

/**
 * Class DrdMigrateFromD7Command.
 *
 * @package Drupal\drd
 */
class DrdMigrateFromD7Command extends DrdCommandBase {

  /**
   * {@inheritdoc}
   */
  protected function configure() {
    parent::configure();
    $this
      ->setName('drd:migrate:from:d7')
      ->setDescription($this->trans('command.drd.migrate.from.d7.description'))
      ->addArgument(
        'inventory',
        InputArgument::REQUIRED,
        $this->trans('command.drd.migrate.from.d7.arguments.inventory')
      );
  }

  /**
   * @inheritDoc
   */
  protected function execute(InputInterface $input, OutputInterface $output) {
    if (!file_exists($input->getArgument('inventory'))) {
      $output->writeln('Inventory file does not exist!');
      return;
    }
    try {
      $inventory = Json::decode(file_get_contents($input->getArgument('inventory')));
    }
    catch (\Exception $ex) {
      $output->writeln('Inventory file can not be read!');
      return;
    }
    $this->promoteUser();
    $storage = \Drupal::entityTypeManager()->getStorage('drd_core');

    foreach ($inventory as $id => $coredomains) {
      $output->writeln('Import core ' . $id);
      /** @var DrdCore $core */
      $core = $storage->create([
        'name' => 'Migrate ' . $id,
      ]);
      foreach ($coredomains as $coredomain) {
        $url = $coredomain['ssl'] ? 'https://' : 'http://';
        $url .= $coredomain['url'];
        $output->writeln('  Import ' . $url);
        $domain = DrdDomain::instanceFromUrl($core, $url, []);
        if ($domain->isNew()) {
          $domain->initValues($coredomain['url']);
        }
        else {
          $core = $domain->getCore();
        }
        if ($domain->pushOTT($coredomain['token'])) {
          if ($core->isNew()) {
            // Try to find the correct host or create a new one.
            $host = DrdHost::findOrCreateByHost(parse_url($url, PHP_URL_HOST));
            $core->setHost($host);
            if (!$domain->initCore($core)) {
              continue;
            }
          }
          $domain->set('installed', 1);
          $domain->setCore($core);
          $domain->save();
          $core = $domain->getCore();
        }
      }
    }
  }

}
