<?php

/**
 * @file
 * Contains \Drupal\drd\DrdCoreAccessControlHandler.
 */

namespace Drupal\drd;

use Drupal\Core\Entity\EntityAccessControlHandler;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Access\AccessResult;

/**
 * Access controller for the Core entity.
 *
 * @see \Drupal\drd\Entity\DrdCore.
 */
class DrdCoreAccessControlHandler extends EntityAccessControlHandler {
  /**
   * {@inheritdoc}
   */
  protected function checkAccess(EntityInterface $entity, $operation, AccountInterface $account) {
    switch ($operation) {
      case 'view':
        if (!$entity->isPublished()) {
          return AccessResult::allowedIfHasPermission($account, 'view unpublished core entities');
        }
        return AccessResult::allowedIfHasPermission($account, 'view published core entities');

      case 'update':
        return AccessResult::allowedIfHasPermission($account, 'edit core entities');

      case 'delete':
        return AccessResult::allowedIfHasPermission($account, 'delete core entities');
    }

    return AccessResult::allowed();
  }

  /**
   * {@inheritdoc}
   */
  protected function checkCreateAccess(AccountInterface $account, array $context, $entity_bundle = NULL) {
    return AccessResult::allowedIfHasPermission($account, 'add core entities');
  }

}
