<?php

/**
 * @file
 * Contains \Drupal\drd\DrdDomainAccessControlHandler.
 */

namespace Drupal\drd;

use Drupal\Core\Entity\EntityAccessControlHandler;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Access\AccessResult;

/**
 * Access controller for the Domain entity.
 *
 * @see \Drupal\drd\Entity\DrdDomain.
 */
class DrdDomainAccessControlHandler extends EntityAccessControlHandler {
  /**
   * {@inheritdoc}
   */
  protected function checkAccess(EntityInterface $entity, $operation, AccountInterface $account) {
    switch ($operation) {
      case 'view':
        if (!$entity->isPublished()) {
          return AccessResult::allowedIfHasPermission($account, 'view unpublished domain entities');
        }
        return AccessResult::allowedIfHasPermission($account, 'view published domain entities');

      case 'update':
        return AccessResult::allowedIfHasPermission($account, 'edit domain entities');

      case 'delete':
        return AccessResult::allowedIfHasPermission($account, 'delete domain entities');
    }

    return AccessResult::allowed();
  }

  /**
   * {@inheritdoc}
   */
  protected function checkCreateAccess(AccountInterface $account, array $context, $entity_bundle = NULL) {
    return AccessResult::allowedIfHasPermission($account, 'add domain entities');
  }

}
