<?php

/**
 * @file
 * Contains \Drupal\drd\DrdDomainInterface.
 */

namespace Drupal\drd;

use Drupal\Core\Url;
use Drupal\drd\Entity\DrdCore;

/**
 * Provides an interface for defining Domain entities.
 *
 * @ingroup drd
 */
interface DrdDomainInterface extends DrdRemoteInterface {

  /**
   * Gets the Domain core.
   *
   * @return DrdCore
   *   Core of the Domain.
   */
  public function getCore();

  /**
   * Sets the Domain core.
   *
   * @param DrdCore $core
   *   The Domain core.
   *
   * @return \Drupal\drd\DrdDomainInterface
   *   The called Domain entity.
   */
  public function setCore($core);

  /**
   * @param string|null $type
   * @param bool $for_remote
   * @return array
   */
  public function getAuthSetting($type = NULL, $for_remote = FALSE);

  /**
   * @param string|null $type
   * @return array
   */
  public function getCryptSetting($type = NULL);

  /**
   * @param DrdCore $core
   * @param string $uri
   * @param array $extra_values
   * @return \Drupal\drd\DrdDomainInterface
   * @throws \Exception
   */
  public static function instanceFromUrl($core, $uri, $extra_values);

  /**
   * @return Url
   */
  public function buildUrl();

  /**
   * @return mixed
   *  - FALSE if we can't connect to the given domain
   *  - empty string if we were able to connect but without the expected DRD result
   *  - the response from the remote DRD as an array
   */
  public function getSupportedCryptMethods();

  /**
   * @param string $token
   * @return bool
   */
  public function pushOTT($token);

  /**
   * @return bool
   */
  public function isDefaultPort();

  /**
   * @var string|bool $redirect
   * @return string
   */
  public function getRemoteSetupToken($redirect);

  /**
   * @var string $label
   * @var bool $initial
   * @return string
   */
  public function getRemoteSetupLink($label, $initial = FALSE);

  /**
   * @return bool
   */
  public function ping();

  /**
   * @return array
   */
  public function remoteInfo();

  /**
   * @param DrdCore $core
   * @throws \Exception
   */
  public function initCore($core);

  /**
   * @param string $name
   * @param string $crypt
   * @param array $crypt_setting
   * @return
   */
  public function initValues($name, $crypt = NULL, $crypt_setting = []);

  /**
   * Callback to retrieve all domains from the remote Drupal installation.
   *
   * @param \Drupal\drd\Entity\DrdCore $core
   */
  public function retrieveAllDomains($core);

  /**
   * @param array $aliase
   * @return \Drupal\drd\DrdDomainInterface
   *   The called Domain entity.
   */
  public function setAliase($aliase);

  /**
   * @return array
   */
  public function getReleases();

  /**
   * @param array $release
   * @return \Drupal\drd\DrdDomainInterface
   *   The called Domain entity.
   */
  public function setReleases($releases);

  /**
   * @param bool $refresh
   * @return bool
   */
  public function getMaintenanceMode($refresh = TRUE);

  /**
   * @param bool $refresh
   * @return string|bool
   */
  public function getRemoteBlock($module, $delta, $refresh = TRUE);

  /**
   * @param bool $refresh
   * @return string|bool
   */
  public function getRequirements($refresh = TRUE);

  /**
   * @param array $messages
   * @return \Drupal\drd\DrdDomainInterface
   *   The called Domain entity.
   */
  public function cacheRemoteMessages($messages);

  /**
   * @param bool $mode
   * @return \Drupal\drd\DrdDomainInterface
   *   The called Domain entity.
   */
  public function cacheMaintenanceMode($mode);

  /**
   * @param $module
   * @param $delta
   * @param $content
   * @return \Drupal\drd\DrdDomainInterface
   *   The called Domain entity.
   */
  public function cacheBlock($module, $delta, $content);

  /**
   * @param string $log
   * @return \Drupal\drd\DrdDomainInterface
   *   The called Domain entity.
   */
  public function cacheErrorLog($log);

  /**
   * @param array $requirements
   * @return \Drupal\drd\DrdDomainInterface
   *   The called Domain entity.
   */
  public function cacheRequirements($requirements);

  /**
   * @param array $variables
   * @return \Drupal\drd\DrdDomainInterface
   *   The called Domain entity.
   */
  public function cacheVariables($variables);

  /**
   * @param array $globals
   * @return \Drupal\drd\DrdDomainInterface
   *   The called Domain entity.
   */
  public function cacheGlobals($globals);

}
