<?php

/**
 * @file
 * Contains \Drupal\drd\DrdMajorAccessControlHandler.
 */

namespace Drupal\drd;

use Drupal\Core\Entity\EntityAccessControlHandler;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Access\AccessResult;

/**
 * Access controller for the Major Version entity.
 *
 * @see \Drupal\drd\Entity\DrdMajor.
 */
class DrdMajorAccessControlHandler extends EntityAccessControlHandler {
  /**
   * {@inheritdoc}
   */
  protected function checkAccess(EntityInterface $entity, $operation, AccountInterface $account) {
    switch ($operation) {
      case 'view':
        if (!$entity->isPublished()) {
          return AccessResult::allowedIfHasPermission($account, 'view unpublished major version entities');
        }
        return AccessResult::allowedIfHasPermission($account, 'view published major version entities');

      case 'update':
        return AccessResult::allowedIfHasPermission($account, 'edit major version entities');

      case 'delete':
        return AccessResult::allowedIfHasPermission($account, 'delete major version entities');
    }

    return AccessResult::allowed();
  }

  /**
   * {@inheritdoc}
   */
  protected function checkCreateAccess(AccountInterface $account, array $context, $entity_bundle = NULL) {
    return AccessResult::allowedIfHasPermission($account, 'add major version entities');
  }

}
