<?php

/**
 * @file
 * Contains \Drupal\drd\DrdProjectAccessControlHandler.
 */

namespace Drupal\drd;

use Drupal\Core\Entity\EntityAccessControlHandler;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Access\AccessResult;

/**
 * Access controller for the Project entity.
 *
 * @see \Drupal\drd\Entity\DrdProject.
 */
class DrdProjectAccessControlHandler extends EntityAccessControlHandler {
  /**
   * {@inheritdoc}
   */
  protected function checkAccess(EntityInterface $entity, $operation, AccountInterface $account) {
    switch ($operation) {
      case 'view':
        if (!$entity->isPublished()) {
          return AccessResult::allowedIfHasPermission($account, 'view unpublished project entities');
        }
        return AccessResult::allowedIfHasPermission($account, 'view published project entities');

      case 'update':
        return AccessResult::allowedIfHasPermission($account, 'edit project entities');

      case 'delete':
        return AccessResult::allowedIfHasPermission($account, 'delete project entities');
    }

    return AccessResult::allowed();
  }

  /**
   * {@inheritdoc}
   */
  protected function checkCreateAccess(AccountInterface $account, array $context, $entity_bundle = NULL) {
    return AccessResult::allowedIfHasPermission($account, 'add project entities');
  }

}
