<?php

/**
 * @file
 * Contains \Drupal\drd\DrdReleaseInterface.
 */

namespace Drupal\drd;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Entity\EntityChangedInterface;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\drd\Entity\DrdMajor;
use Drupal\user\EntityOwnerInterface;

/**
 * Provides an interface for defining Release entities.
 *
 * @ingroup drd
 */
interface DrdReleaseInterface extends ContentEntityInterface, EntityChangedInterface, EntityOwnerInterface {
  // Add get/set methods for your configuration properties here.

  /**
   * Gets the Release version.
   *
   * @return string
   *   Version of the Release.
   */
  public function getVersion();

  /**
   * Sets the Release version.
   *
   * @param string $version
   *   The Release version.
   *
   * @return \Drupal\drd\DrdReleaseInterface
   *   The called Release entity.
   */
  public function setVersion($version);

  /**
   * Gets the Release Major Version.
   *
   * @return DrdMajor
   *   Major Version of the Release.
   */
  public function getMajor();

  /**
   * Sets the Release Major Version.
   *
   * @param DrdMajor $major
   *   The Release Major Version.
   *
   * @return \Drupal\drd\DrdReleaseInterface
   *   The called Release entity.
   */
  public function setMajor($major);

  /**
   * Gets the Release creation timestamp.
   *
   * @return int
   *   Creation timestamp of the Release.
   */
  public function getCreatedTime();

  /**
   * Sets the Release creation timestamp.
   *
   * @param int $timestamp
   *   The Release creation timestamp.
   *
   * @return \Drupal\drd\DrdReleaseInterface
   *   The called Release entity.
   */
  public function setCreatedTime($timestamp);

  /**
   * Returns the Release published status indicator.
   *
   * Unpublished Release are only visible to restricted users.
   *
   * @return bool
   *   TRUE if the Release is published.
   */
  public function isPublished();

  /**
   * Sets the published status of a Release.
   *
   * @param bool $published
   *   TRUE to set this Release to published, FALSE to set it to unpublished.
   *
   * @return \Drupal\drd\DrdReleaseInterface
   *   The called Release entity.
   */
  public function setPublished($published);

  /**
   * @param string $type
   * @param string $name
   * @param string $version
   * @return \Drupal\drd\DrdReleaseInterface
   */
  public static function findOrCreate($type, $name, $version);

}
