<?php

/**
 * @file
 * Contains \Drupal\drd\DrdRemoteInterface.
 */

namespace Drupal\drd;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Entity\EntityChangedInterface;
use Drupal\user\EntityOwnerInterface;

/**
 * Provides an interface for defining DrdCore and DrdDomain entities.
 *
 * @ingroup drd
 */
interface DrdRemoteInterface extends ContentEntityInterface, EntityChangedInterface, EntityOwnerInterface {

  /**
   * Gets the Host/Core/Domain name.
   *
   * @return string
   *   Name of the Host/Core/Domain.
   */
  public function getName();

  /**
   * Sets the Host/Core/Domain name.
   *
   * @param string $name
   *   The Host/Core/Domain name.
   *
   * @return \Drupal\drd\DrdRemoteInterface
   *   The called Host/Core/Domain entity.
   */
  public function setName($name);

  /**
   * Gets the Host/Core/Domain creation timestamp.
   *
   * @return int
   *   Creation timestamp of the Host/Core/Domain.
   */
  public function getCreatedTime();

  /**
   * Sets the Host/Core/Domain creation timestamp.
   *
   * @param int $timestamp
   *   The Host/Core/Domain creation timestamp.
   *
   * @return \Drupal\drd\DrdRemoteInterface
   *   The called Host/Core/Domain entity.
   */
  public function setCreatedTime($timestamp);

  /**
   * Returns the Host/Core/Domain published status indicator.
   *
   * Unpublished Host/Core/Domain are only visible to restricted users.
   *
   * @return bool
   *   TRUE if the Host/Core/Domain is published.
   */
  public function isPublished();

  /**
   * Sets the published status of a Host/Core/Domain.
   *
   * @param bool $published
   *   TRUE to set this Host/Core/Domain to published, FALSE to set it to unpublished.
   *
   * @return \Drupal\drd\DrdRemoteInterface
   *   The called Host/Core/Domain entity.
   */
  public function setPublished($published);

}
