<?php
/**
 * @file
 * Contains \Drupal\drd\DrdUpdateProcessor.
 */

namespace Drupal\drd;

use Drupal\drd\Entity\DrdMajor;
use Drupal\drd\Entity\DrdProject;
use Drupal\drd\Entity\DrdRelease;
use Drupal\update\UpdateProcessor;

/**
 * Process project update information.
 */
class DrdUpdateProcessor extends UpdateProcessor {

  private function project($name, $type, $core) {
    return [
      'name' => $name,
      'core' => $core . '.x',
      'includes' => [],
      'project_type' => $type,
    ];
  }

  /**
   * @param DrdProject $project
   * @param DrdMajor $major
   * @param DrdRelease $release
   * @param array $available
   */
  private function calculate($project, $major, $release, $available) {
    $project_data = [
      'existing_major' => $major->getMajorVersion(),
      'existing_version' => $release->getVersion(),
      'install_type' => 'official',
    ];
    update_calculate_project_update_status($project_data, $available);
    $release->set('updatestatus', $project_data['status']);
    $release->set('updateinfo', $project_data);
    $release->save();
    if (!empty($project_data['recommended'])) {
      $recommended = DrdRelease::findOrCreate($project->getType(), $project->getName(), $project_data['recommended']);
      if ($release->getVersion() != $recommended->getVersion()) {
        $this->calculate($project, $major, $recommended, $available);
      }
      $major->setRecommendedRelease($recommended);
    }
    if (!empty($project_data['title'])) {
      $project->setLabel($project_data['title']);
    }
  }

  /**
   * {@inheritdoc}
   */
  public function fetchData() {
    module_load_include('inc', 'update', 'update.compare');
    foreach ([8, 7, 6] as $version) {
      $processed = [];
      $ids = \Drupal::entityQuery('drd_major')
        ->condition('coreversion', $version)
        ->condition('hidden', 0)
        ->notExists('parentproject')
        ->execute();
      if (empty($ids)) {
        continue;
      }
      /** @var DrdMajor $major */
      foreach (\Drupal::entityTypeManager()->getStorage('drd_major')->loadMultiple($ids) as $major) {
        $project = $major->getProject();
        if (isset($processed[$project->getName()])) {
          continue;
        }
        $processed[$project->getName()] = TRUE;
        if ($this->processFetchTask($this->project($project->getName(), $project->get('type'), $version))) {
          $available = $this->availableReleasesTempStore->get($project->getName());
          $rids = \Drupal::entityQuery('drd_release')
            ->condition('major', $major->id())
            ->execute();
          /** @var DrdRelease $release */
          foreach (\Drupal::entityTypeManager()->getStorage('drd_release')->loadMultiple($rids) as $release) {
            $this->calculate($project, $major, $release, $available);
          }
          $major->set('information', $available);
          $major->save();
          $project->save();
        }
      }
    }
  }

}
