<?php

/**
 * @file
 * Contains \Drupal\drd\Entity\DrdDomain.
 */

namespace Drupal\drd\Entity;

use Drupal\views\EntityViewsData;
use Drupal\views\EntityViewsDataInterface;

/**
 * Provides Views data for Domain entities.
 */
class DrdDomainViewsData extends EntityViewsData implements EntityViewsDataInterface {
  /**
   * {@inheritdoc}
   */
  public function getViewsData() {
    $data = parent::getViewsData();

    $data['drd_domain']['table']['base'] = [
      'field' => 'id',
      'title' => $this->t('Domain'),
      'help' => $this->t('The Domain ID.'),
    ];

    $data['drd_domain']['status']['filter']['label'] = $this->t('Active');
    $data['drd_domain']['status']['filter']['type'] = 'yes-no';

    $data['drd_domain']['installed']['filter']['label'] = $this->t('Installed');
    $data['drd_domain']['installed']['filter']['type'] = 'yes-no';

    $data['drd_domain']['secure']['filter']['label'] = $this->t('SSL');
    $data['drd_domain']['secure']['filter']['type'] = 'yes-no';

    $data['drd_domain']['domain_status_view_field'] = [
      'title' => $this->t('Domain status'),
      'field' => [
        'title' => $this->t('Domain status'),
        'help' => $this->t('Show the status of the domain with colored icons'),
        'id' => 'domain_status_view_field',
      ],
    ];

    $data['drd_domain']['drd_bulk_form'] = [
      'title' => $this->t('Bulk update'),
      'help' => $this->t('Add a form element that lets you run operations on multiple domains.'),
      'field' => [
        'id' => 'drd_bulk_form',
      ],
    ];

    $data['drd_domain__releases']['entity_id'] = [
      'relationship' => [
        'title' => $this->t('Domains'),
        'help' => $this->t('TBD.'),
        'id' => 'standard',
        'base' => 'drd_domain',
        'base field' => 'id',
        'field' => 'entity_id',
        'label' => $this->t('domains'),
      ],
    ];

    $data['drd_domain__warnings']['entity_id'] = [
      'relationship' => [
        'title' => $this->t('Domains'),
        'help' => $this->t('TBD.'),
        'id' => 'standard',
        'base' => 'drd_domain',
        'base field' => 'id',
        'field' => 'entity_id',
        'label' => $this->t('domains'),
      ],
    ];

    $data['drd_domain__errors']['entity_id'] = [
      'relationship' => [
        'title' => $this->t('Domains'),
        'help' => $this->t('TBD.'),
        'id' => 'standard',
        'base' => 'drd_domain',
        'base field' => 'id',
        'field' => 'entity_id',
        'label' => $this->t('domains'),
      ],
    ];

    return $data;
  }

}
