<?php

namespace Drupal\drd\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\drd\ContextProvider\DrdRouteContext;
use Drupal\drd\DrdRemoteActionsInterface;

/**
 * Class DrdRemoteActionForm.
 *
 * @package Drupal\drd\Form
 */
class DrdRemoteActionForm extends FormBase {

  /**
   * @var DrdRemoteActionsInterface
   */
  private $actionService;

  /**
   * @var DrdRouteContext
   */
  private $context;

  /**
   * @inheritDoc
   */
  public function __construct() {
    $this->context = DrdRouteContext::findDrdContext();
    if ($this->context) {
      $this->actionService = \Drupal::service('drd.remote.actions');
      $this->actionService->setMode($this->context->getType());
    }
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'drd_remote_action_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    if ($this->context) {
      $this->actionService->buildForm($form, $form_state);
    }
    return $form;
  }

  /**
    * {@inheritdoc}
    */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);
    $this->actionService->validateForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->actionService->submitForm($form, $form_state, $this->context->getEntity());
    if ($this->actionService->getExecutedCount()) {
      drupal_set_message(t('%action was queued for this item.', array(
        '%action' => $this->actionService->getSelectedAction()->label(),
      )));
    }
  }

}
