<?php

/**
 * @file
 * Contains \Drupal\drd\Form\DrdRequirementForm.
 */

namespace Drupal\drd\Form;

use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Ajax\DataCommand;
use Drupal\Core\Ajax\HtmlCommand;
use Drupal\Core\Ajax\InvokeCommand;
use Drupal\drd\Crypt\DrdCryptBase;
use Drupal\drd\Entity\DrdCore;
use Drupal\Core\Entity\ContentEntityForm;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Language\Language;
use Drupal\drd\Entity\DrdDomain;
use Drupal\drd\Entity\DrdRequirement;
use Drupal\drd\Plugin\DrdAuthManager;

/**
 * Form controller for Requirement edit forms.
 *
 * @ingroup drd
 */
class DrdRequirementForm extends ContentEntityForm {
  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    /* @var $requirement \Drupal\drd\Entity\DrdRequirement */
    $form = parent::buildForm($form, $form_state);
    $requirement = $this->entity;

    $form['langcode'] = [
      '#title' => $this->t('Language'),
      '#type' => 'language_select',
      '#default_value' => $requirement->langcode->value,
      '#languages' => Language::STATE_ALL,
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state) {
    /** @var DrdRequirement $requirement */
    $requirement = $this->entity;
    $status = $requirement->save();

    switch ($status) {
      case SAVED_NEW:
        drupal_set_message($this->t('Created the %label Requirement. ', [
          '%label' => $requirement->label(),
        ]));
        break;

      default:
        drupal_set_message($this->t('Saved the %label Requirement.', [
          '%label' => $requirement->label(),
        ]));
    }
    $form_state->setRedirect('entity.drd_requirement.edit_form', ['drd_requirement' => $requirement->id()]);
  }

}
