<?php

/**
 * @file
 * Contains \Drupal\drd\Plugin\Action\DrdActionBlocks.
 */

namespace Drupal\drd\Plugin\Action;

use Drupal\drd\Entity\DrdDomain;
use Drupal\drd\Plugin\DrdActionRemoteBase;

/**
 * Provides a 'DrdActionBlocks' action.
 *
 * @Action(
 *  id = "drd_action_blocks",
 *  label = @Translation("List and render blocks"),
 *  type = "drd_domain",
 * )
 */
class DrdActionBlocks extends DrdActionRemoteBase {
  /**
   * {@inheritdoc}
   */
  public function execute($domain = NULL) {
    /** @var DrdDomain $domain */
    $response = parent::execute($domain);
    if ($response) {
      if (empty($this->arguments['module'])) {
        $site_config = \Drupal::configFactory()->getEditable('drd.general');
        $blocks = $site_config->get('remote_blocks');
        foreach ($response as $module => $items) {
          foreach ($items as $delta => $label) {
            $blocks[$module][$delta] = $label;
          }
        }
        $site_config
          ->set('remote_blocks', $blocks)
          ->save();
      }
      else {
        $domain->cacheBlock(
          $this->arguments['module'],
          $this->arguments['delta'],
          $response['data']
        );
      }
      return TRUE;
    }
    return FALSE;
  }

}
