<?php

/**
 * @file
 * Contains \Drupal\drd\Plugin\Action\DrdActionDomainsEnableAll.
 */

namespace Drupal\drd\Plugin\Action;

use Drupal\drd\Entity\DrdCore;
use Drupal\drd\Entity\DrdDomain;
use Drupal\drd\Plugin\DrdActionRemoteCoreBase;

/**
 * Provides a 'DrdActionDomainsEnableAll' action.
 *
 * @Action(
 *  id = "drd_action_domains_enableall",
 *  label = @Translation("Enable all domains"),
 *  type = "drd_core",
 * )
 */
class DrdActionDomainsEnableAll extends DrdActionRemoteCoreBase {
  /**
   * @inheritDoc
   */
  public function execute($core = NULL) {
    if (empty($core)) {
      return FALSE;
    }
    /** @var DrdCore $core */

    // Get drush and drupalconsole settings from host
    $drush = $core->getHost()->getDrush();
    $drupalconsole = $core->getHost()->getDrupalConsole();
    if (empty($drush) && empty($drupalconsole)) {
      return FALSE;
    }
    $this->setActionArgument('drush', $drush);
    $this->setActionArgument('drupalconsole', $drupalconsole);

    // Get all disabled domains from same core
    $domains = $core->getDomains(['installed' => 0]);
    if (empty($domains)) {
      return TRUE;
    }
    $urls = [];
    $local = [];
    foreach ($domains as $d) {
      /** @var DrdDomain $d */
      $url = $d->buildUrl()->toString();
      $urls[$url] = $d->getRemoteSetupToken(FALSE);
      $local[$url] = $d;
    }
    $this->setActionArgument('urls', $urls);

    // Submit command to remote domain
    $response = parent::execute($core);
    if ($response) {
      foreach ($response as $url) {
        $d = $local[$url];
        $d->set('installed', 1);
        $d->save();
        $d->remoteInfo();
      }
      return TRUE;
    }
    return FALSE;
  }

}
