<?php

/**
 * @file
 * Contains \Drupal\drd\Plugin\Action\DrdActionDomainsReceive.
 */

namespace Drupal\drd\Plugin\Action;

use Drupal\drd\Entity\DrdCore;
use Drupal\drd\Entity\DrdDomain;
use Drupal\drd\Plugin\DrdActionRemoteCoreBase;

/**
 * Provides a 'DrdActionDomainsReceive' action.
 *
 * @Action(
 *  id = "drd_action_domains_receive",
 *  label = @Translation("Receive domains"),
 *  type = "drd_core",
 * )
 */
class DrdActionDomainsReceive extends DrdActionRemoteCoreBase {
  /**
   * @inheritDoc
   */
  public function execute($core = NULL) {
    /** @var DrdCore $core */
    $response = parent::execute($core);
    if (!$response) {
      return FALSE;
    }

    $crypt = $this->domain->get('crypt')->value;
    $crypt_setting = $this->domain->getCryptSetting();

    foreach ($response as $shortname => $item) {
      $d = DrdDomain::instanceFromUrl($core, 'http://' . $item['uri'], []);
      if ($d->isNew()) {
        if ($d->ping()) {
          $d->remoteInfo();
        }
        else {
          $d->initValues($item['uri'], $crypt, $crypt_setting);
        }
      }
      $d
        ->setAliase($item['aliase'])
        ->save();
    }

    return TRUE;
  }

}
