<?php

/**
 * @file
 * Contains \Drupal\drd\Plugin\Action\DrdActionLibrary.
 */

namespace Drupal\drd\Plugin\Action;

use Drupal\Core\Url;
use Drupal\drd\Entity\DrdDomain;
use Drupal\Core\Form\FormStateInterface;
use Drupal\drd\Plugin\DrdActionRemoteBase;
use Drupal\drd\Plugin\DrdActionConfigurableInterface;

/**
 * Provides a 'DrdActionLibrary' action.
 *
 * @Action(
 *  id = "drd_action_library",
 *  label = @Translation("Library"),
 *  type = "drd_domain",
 * )
 */
class DrdActionLibrary extends DrdActionRemoteBase implements DrdActionConfigurableInterface {

  public function __construct(array $configuration, $plugin_id, $plugin_definition) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->arguments['source'] = 'official';
  }

  /**
   * {@inheritdoc}
   */
  public function execute($domain = NULL) {
    static $build;

    if ($this->arguments['source'] == 'official') {
      $this->arguments['url'] = 'http://cgit.drupalcode.org/drd/plain/build/drd.phar?h=8.x-3.x';
    }
    else {
      if (empty($build)) {
        // Re-build PHAR
        $root = drupal_get_path('module', 'drd');
        $path = $root . '/build/drd.phar';
        if ($this->arguments['source'] == 'local') {
          $url = Url::fromUserInput('/' . $path, ['absolute' => TRUE]);
          $this->arguments['url'] = $url->toString();
        }

        $phar = new \Phar($path, 0, 'drd.phar');
        $phar->buildFromDirectory($root . '/src/Remote');
        $phar->buildFromDirectory($root . '/src/Crypt');
        $phar->setStub($phar->createDefaultStub('index.php'));

        if (PHP_SAPI === 'cli') {
          // We can't determine our own URL and hence have to deliver the content
          // of the file as part of the request.
          $this->arguments['lib'] = base64_encode(file_get_contents($path));
        }
        $build = TRUE;
      }
      if ($this->arguments['source'] == 'none') {
        return TRUE;
      }
    }

    /** @var DrdDomain $domain */
    return parent::execute($domain);
  }
#['official', 'local', 'none']
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $form['drd_action_library_source'] = array(
      '#type' => 'select',
      '#title' => t('Mode'),
      '#default_value' => 'official',
      '#options' => [
        'official' => t('Published version from drupal.org'),
        'local' => t('Local development version'),
        'none' => t('None, update build only'),
      ],
    );
    return $form;
  }

  public function validateConfigurationForm(array &$form, FormStateInterface $form_state) {}

  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    $this->arguments['source'] = $form_state->getValue('drd_action_library_source');
  }

}
