<?php

/**
 * @file
 * Contains \Drupal\drd\Plugin\Action\DrdActionMaintenanceMode.
 */

namespace Drupal\drd\Plugin\Action;

use Drupal\Core\Form\FormStateInterface;
use Drupal\drd\Plugin\DrdActionRemoteBase;
use Drupal\drd\Plugin\DrdActionConfigurableInterface;
use Drupal\drd\Entity\DrdDomain;

/**
 * Provides a 'DrdActionMaintenanceMode' action.
 *
 * @Action(
 *  id = "drd_action_maintenance_mode",
 *  label = @Translation("Maintenance Mode"),
 *  type = "drd_domain",
 * )
 */
class DrdActionMaintenanceMode extends DrdActionRemoteBase implements DrdActionConfigurableInterface {

  public function __construct(array $configuration, $plugin_id, $plugin_definition) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->arguments['mode'] = 'getStatus';
  }

  /**
   * {@inheritdoc}
   */
  public function execute($domain = NULL) {
    /** @var DrdDomain $domain */
    $response = parent::execute($domain);
    if ($response) {
      if ($this->arguments['mode'] == 'getStatus') {
        $domain->cacheMaintenanceMode($response['data']);
      }
      return TRUE;
    }
    return FALSE;
  }

  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $form['drd_action_maintenance_mode'] = array(
      '#type' => 'select',
      '#title' => t('Mode'),
      '#default_value' => 'getStatus',
      '#options' => [
        'getStatus' => t('get maintenance mode'),
        'on' => t('turn on maintenance mode'),
        'off' => t('turn off maintenance mode'),
      ],
    );
    return $form;
  }

  public function validateConfigurationForm(array &$form, FormStateInterface $form_state) {}

  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    $this->arguments['mode'] = $form_state->getValue('drd_action_maintenance_mode');
  }

}
