<?php

/**
 * @file
 * Contains \Drupal\drd\Plugin\Action\DrdActionProjects.
 */

namespace Drupal\drd\Plugin\Action;

use Drupal\drd\Entity\DrdCore;
use Drupal\drd\Entity\DrdDomain;
use Drupal\drd\Entity\DrdMajor;
use Drupal\drd\Entity\DrdProject;
use Drupal\drd\Entity\DrdRelease;
use Drupal\drd\Plugin\DrdActionRemoteBase;

/**
 * Provides a 'DrdActionProjects' action.
 *
 * @Action(
 *  id = "drd_action_projects",
 *  label = @Translation("Get installed projects"),
 *  type = "drd_domain",
 * )
 */
class DrdActionProjects extends DrdActionRemoteBase {
  /**
   * {@inheritdoc}
   */
  public function execute($domain = NULL) {
    /** @var DrdDomain $domain */
    $response = parent::execute($domain);
    if ($response) {
      $releases = [];
      $base_themes = [];
      foreach ($response as $item) {
        $item = (array) $item;
        $info = !empty($item['info']) ? $item['info'] : [
          'hidden' => TRUE,
        ];
        if (empty($info['core'])) {
          $info['core'] = $domain->getCore()->getDrupalRelease()->getVersion();
        }
        if (empty($info['version'])) {
          $info['version'] = $info['core'] . '-0.x';
        }
        /** @var DrdRelease $release */
        $release = DrdRelease::findOrCreate($item['type'], $item['name'], $info['version']);
        /** @var DrdMajor $major */
        $major = $release->getMajor();
        $project = $major->getProject();

        $release->set('information', $item);
        if (!empty($info['name'])) {
          $project->setLabel($info['name']);
        }
        if (empty($info['project'])) {
          $info['hidden'] = TRUE;
        }
        elseif ($info['project'] != $item['name']) {
          $major->setParentProject(DrdProject::findOrCreate($item['type'], $info['project']));
        }
        $major->setHidden(!empty($info['hidden']));
        if (!empty($info['base theme']) && !in_array($info['base theme'], $base_themes)) {
          $base_themes[] = $info['base theme'];
        }

        $release->save();
        $major->save();
        $project->save();
        if (!empty($item['status'])) {
          $releases[] = $release;
        }
      }
      foreach ($base_themes as $base_theme) {
        $releases[] = DrdRelease::findOrCreate('theme', $base_theme, $this->findVersion($response, $base_theme));
      }
      $domain->setReleases($releases);
      $domain->save();
      return TRUE;
    }
    return FALSE;
  }

  private function findVersion($items, $name) {
    foreach ($items as $item) {
      $item = (array) $item;
      if (!empty($item['name']) && $item['name'] == $name) {
        return empty($item['info']['version']) ? $item['info']['core'] . '-0.x' : $item['info']['version'];
      }
    }
    return '0.x-0.x';
  }

}
