<?php

namespace Drupal\drd\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\drd\ContextProvider\DrdRouteContext;
use Symfony\Component\DependencyInjection\ContainerInterface;

abstract class DomainBlockBase extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * @var DrdRouteContext.
   */
  protected $context;

  /**
   * Creates a RemoteBlock instance.
   *
   * @param array $configuration
   * @param string $plugin_id
   * @param array $plugin_definition
   * @param DrdRouteContext $context
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, $context) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->context = $context;
  }

  /**
   * @inheritDoc
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      DrdRouteContext::findDrdContext()
    );
  }

  /**
   * @inheritDoc
   */
  public function getCacheMaxAge() {
    return 0;
  }

  protected function isDrdContext() {
    return $this->context ? (bool) $this->context->getEntity() : FALSE;
  }

  protected function getEntity() {
    return $this->context ? $this->context->getEntity() : FALSE;
  }

}
