<?php

/**
 * @file
 * Contains \Drupal\drd\Plugin\views\field\DomainStatusViewField.
 */

namespace Drupal\drd\Plugin\views\field;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Render\Markup;
use Drupal\drd\Entity\DrdDomain;
use Drupal\drd\Entity\DrdRequirement;
use Drupal\views\Plugin\views\field\FieldPluginBase;
use Drupal\views\ResultRow;

/**
 * A handler to provide a field that is completely custom by the administrator.
 *
 * @ingroup views_field_handlers
 *
 * @ViewsField("domain_status_view_field")
 */
class DomainStatusViewField extends FieldPluginBase {
  /**
   * {@inheritdoc}
   */
  public function usesGroupBy() {
    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function query() {
    // do nothing -- to override the parent query.
  }

  /**
   * {@inheritdoc}
   */
  protected function defineOptions() {
    $options = parent::defineOptions();

    $options['hide_alter_empty'] = array('default' => FALSE);
    return $options;
  }

  /**
   * {@inheritdoc}
   */
  public function buildOptionsForm(&$form, FormStateInterface $form_state) {
    parent::buildOptionsForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function render(ResultRow $values) {
    /** @var DrdDomain $domain */
    $domain = $values->_entity;
    $warnings = $this->getCategories($domain, 'warnings');
    $errors = $this->getCategories($domain, 'errors');

    $allCategories = DrdRequirement::getCategoryKeys();

    $output = '';
    foreach ($allCategories as $category) {
      $class = [$category];
      if (in_array($category, $errors)) {
        $class[] = 'error';
      }
      else if (in_array($category, $warnings)) {
        $class[] = 'warning';
      }
      else {
        $class[] = 'ok';
      }
      $output .= '<span title="' . $category . '" class="' . implode(' ', $class) . '">' . $category . '</span>';
    }
    return Markup::create('<div class="drd-domain-status">' . $output . '</div>');
  }

  /**
   * @param DrdDomain $domain
   * @param string $field
   * @return array
   */
  private function getCategories($domain, $field) {
    $ids = [];
    foreach ($domain->get($field)->getValue() as $value) {
      $ids[] = $value['target_id'];
    }

    if (empty($ids)) {
      return [];
    }

    $categories = \Drupal::database()->select('drd_requirement', 'r')
      ->fields('r', ['category'])
      ->distinct()
      ->condition('r.id', $ids, 'IN')
      ->execute()
      ->fetchAllKeyed(0, 0);
    return $categories;
  }
}
