<?php

/**
 * @file
 * Contains \Drupal\drd\Remote\Action7\DrdActionBase.
 */

namespace Drupal\drd\Remote\Action7;
use Drupal\drd\Crypt\DrdCryptBase;

/**
 * Base class for Remote DRD Action Code for Drupal 7.
 */
abstract class DrdActionBase extends \Drupal\drd\Remote\DrdActionBase {
  /**
   * @inheritDoc
   */
  public static function promoteUser() {
    global $user;
    $user = user_load(1);
  }

  /**
   * @inheritDoc
   */
  public static function getCryptInstance($uuid) {
    $authorised = variable_get('drd_remote_authorised', array());
    if (empty($authorised[$uuid])) {
      return FALSE;
    }

    return DrdCryptBase::getInstance(
      $authorised[$uuid]['crypt'],
      (array) $authorised[$uuid]['cryptsetting']
    );
  }

  /**
   * @inheritDoc
   */
  public static function watchdog($message, $variables = array(), $severity = 5, $link = NULL) {
    if (self::getDebugMode()) {
      watchdog('DRD Remote', $message, $variables, $severity, $link);
    }
  }

  /**
   * @inheritDoc
   */
  public static function ott($token, $config) {
    $ott = variable_get('drd_remote_ott', FALSE);
    if (!$ott) {
      self::watchdog('No OTT available', array(), WATCHDOG_ERROR);
      return FALSE;
    }
    variable_del('drd_remote_ott');
    if (empty($ott['expires']) || $ott['expires'] < REQUEST_TIME) {
      self::watchdog('OTT expired', array(), WATCHDOG_ERROR);
      return FALSE;
    }
    if (empty($ott['token']) || $ott['token'] != $token) {
      self::watchdog('Token missmatch: !local / !remote', array('!local' => $ott['token'], '!remote' => $token), WATCHDOG_ERROR);
      return FALSE;
    }

    include_once drupal_get_path('module', 'drd_remote') . '/drd_remote.admin.inc';
    drd_remote_setup($config);
    self::watchdog('OTT config completed', array(), WATCHDOG_INFO);
    return TRUE;
  }

}
