<?php

/**
 * @file
 * Contains \Drupal\drd\Remote\Action8\DrdActionBase.
 */

namespace Drupal\drd\Remote\Action8;

use Drupal\drd\Crypt\DrdCryptBase;
use Psr\Log\LogLevel;

/**
 * Base class for Remote DRD Action Code for Drupal 8.
 */
abstract class DrdActionBase extends \Drupal\drd\Remote\DrdActionBase {
  /**
   * @inheritDoc
   */
  public static function promoteUser() {
    global $user;
    $user = \Drupal\user\Entity\User::load(1);
  }

  /**
   * @inheritDoc
   */
  public static function getCryptInstance($uuid) {
    $config = \Drupal::configFactory()->get('drd_remote.settings');
    $authorised = $config->get('authorised');
    if (empty($authorised[$uuid])) {
      return FALSE;
    }

    return DrdCryptBase::getInstance(
      $authorised[$uuid]['crypt'],
      (array) $authorised[$uuid]['cryptsetting']
    );
  }

  /**
   * @inheritDoc
   */
  public static function watchdog($message, $variables = array(), $severity = 5, $link = NULL) {
    if (self::getDebugMode()) {
      if ($link) {
        $variables['link'] = $link;
      }
      \Drupal::logger('DRD Remote')->log($severity, $message, $variables);
    }
  }

  /**
   * @inheritDoc
   */
  public static function ott($token, $config) {
    $config = \Drupal::configFactory()->getEditable('drd_remote.settings');
    $ott = $config->get('ott');
    if (!$ott) {
      self::watchdog('No OTT available', array(), LogLevel::ERROR);
      return FALSE;
    }
    $config->clear('ott');
    if (empty($ott['expires']) || $ott['expires'] < REQUEST_TIME) {
      self::watchdog('OTT expired', array(), LogLevel::ERROR);
      return FALSE;
    }
    if (empty($ott['token']) || $ott['token'] != $token) {
      self::watchdog('Token missmatch: !local / !remote', array('!local' => $ott['token'], '!remote' => $token), LogLevel::ERROR);
      return FALSE;
    }

    $service = \Drupal::service('drd_remote.setup');
    $service->run($config);
    self::watchdog('OTT config completed', array(), LogLevel::INFO);
    return TRUE;
  }

}
