<?php

/**
 * @file
 * Contains \Drupal\drd\Remote\Action8\DrdActionUserCredentials.
 */

namespace Drupal\drd\Remote\Action8;

use Drupal\user\Entity\User;

/**
 * Provides a 'DrdActionUserCredentials' code.
 */
class DrdActionUserCredentials extends DrdActionBase {
  /**
   * @inheritDoc
   */
  public function execute() {
    $args = $this->getArguments();
    $account = User::load($args['uid']);
    if (!$account) {
      drupal_set_message('User does not exist.', 'error');
    }
    else {
      $this->setUsername($account, $args);
      $this->setPassword($account, $args);
      $this->setStatus($account, $args);
      try {
        $account->save();
      }
      catch (\Exception $ex) {
        drupal_set_message('Changing user credentials failed.', 'error');
      }
    }
    return array();
  }

  /**
   * @param User $account
   * @param array $args
   */
  private function setUsername($account, $args) {
    if (empty($args['username'])) {
      return;
    }
    $check = user_validate_name($args['username']);
    if (!empty($check)) {
      drupal_set_message($check, 'error');
      return;
    }
    $user = user_load_by_name($args['username']);
    if (!empty($user) && $user->uid !== $args['uid']) {
      drupal_set_message('Username already taken.', 'error');
      return;
    }
    $account->setUsername($args['username']);
  }

  /**
   * @param User $account
   * @param array $args
   */
  private function setPassword($account, $args) {
    if (empty($args['password'])) {
      return;
    }
    $account->setPassword($args['password']);
  }

  /**
   * @param User $account
   * @param array $args
   */
  private function setStatus($account, $args) {
    if (!isset($args['status'])) {
      return;
    }
    if ($args['status']) {
      $account->activate();
    }
    else {
      $account->block();
    }
  }

}
